laddu
=====

``laddu`` is an library for analyzing particle physics data. It is written in Rust with bindings to Python which are documented here.

Right now, this page just documents the basic Python API of the library, but the plan is to eventually write a tutorial here for general use. See the `GitHub Repository <https://github.com/denehoffman/laddu>`_ for more details.

.. toctree::
   :caption: API Reference
   :maxdepth: 2
   :name: sec-api

   modules/index
